==> tuia-advert-center-api-1.5.9-20180814.105924-50-sources.jar: cn/com/duiba/tuia/core/api/dto/OligrachTradeDto.java <==
package cn.com.duiba.tuia.core.api.dto;

import cn.com.duiba.tuia.core.api.dto.advert.OligrachAdvertiserDto;

import java.util.List;

/**
 * Created by huangch on 2018/8/8 16:33
 * description:
 *
 * @since JDK 1.6
 */
public class OligrachTradeDto {

    //主键ID，进行删除、编辑、添加广告主操作的时候需要传入
    private Long id;

    //寡头广告主数量
    private Integer oligrachAdvertiserNum;

    //期望新增的广告主
    private Integer expectKaNum;

    //新行业名称
    private String newTradeName;

    //添加的寡头广告主列表
    private List<OligrachAdvertiserDto> oligrachAdvertiserList;

    public String getNewTradeName() {
        return newTradeName;
    }

    public void setNewTradeName(String newTradeName) {
        this.newTradeName = newTradeName;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Integer getOligrachAdvertiserNum() {
        return oligrachAdvertiserNum;
    }

    public void setOligrachAdvertiserNum(Integer oligrachAdvertiserNum) {
        this.oligrachAdvertiserNum = oligrachAdvertiserNum;
    }

    public Integer getExpectKaNum() {
        return expectKaNum;
    }

    public void setExpectKaNum(Integer expectKaNum) {
        this.expectKaNum = expectKaNum;
    }

    public List<OligrachAdvertiserDto> getOligrachAdvertiserList() {
        return oligrachAdvertiserList;
    }

    public void setOligrachAdvertiserList(List<OligrachAdvertiserDto> oligrachAdvertiserList) {
        this.oligrachAdvertiserList = oligrachAdvertiserList;
    }
}

==> tuia-advert-center-api-2.2.78-sources.jar: cn/com/duiba/tuia/core/api/dto/OligrachTradeDto.java <==
package cn.com.duiba.tuia.core.api.dto;

import cn.com.duiba.tuia.core.api.dto.advert.OligrachAdvertiserDto;

import java.io.Serializable;
import java.util.List;

/**
 * Created by huangch on 2018/8/8 16:33
 * description:
 *
 * @since JDK 1.6
 */
public class OligrachTradeDto  implements Serializable {

    private static final long serialVersionUID = 7093957885012718356L;
    //主键ID，进行删除、编辑、添加广告主操作的时候需要传入
    private Long id;

    //寡头广告主数量
    private Integer oligrachAdvertiserNum;

    //期望新增的广告主
    private Integer expectKaNum;

    //新行业名称
    private String newTradeName;

    //添加的寡头广告主列表
    private List<OligrachAdvertiserDto> oligrachAdvertiserList;

    public String getNewTradeName() {
        return newTradeName;
    }

    public void setNewTradeName(String newTradeName) {
        this.newTradeName = newTradeName;
    }

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Integer getOligrachAdvertiserNum() {
        return oligrachAdvertiserNum;
    }

    public void setOligrachAdvertiserNum(Integer oligrachAdvertiserNum) {
        this.oligrachAdvertiserNum = oligrachAdvertiserNum;
    }

    public Integer getExpectKaNum() {
        return expectKaNum;
    }

    public void setExpectKaNum(Integer expectKaNum) {
        this.expectKaNum = expectKaNum;
    }

    public List<OligrachAdvertiserDto> getOligrachAdvertiserList() {
        return oligrachAdvertiserList;
    }

    public void setOligrachAdvertiserList(List<OligrachAdvertiserDto> oligrachAdvertiserList) {
        this.oligrachAdvertiserList = oligrachAdvertiserList;
    }
}
